/* Tran Dang Tuan Anh (problem setter)
   Solution: O(Nlog(10^9+7))

   T and T' are valid pre-order and post-order of a tree iff the first element of T and the last element of T' are the same.
   When erase those elements, T can be divided into <= k parts and T' can be divided into the same number of parts
   and they can pair up with each other to be a valid pre-order and post-order of a k-ary tree.

   The number of tree configurations can be calculated by multiply C(K, deg[u]) for all u in which C(n, k) = n!/k!/(n - k)!.
*/

#include <cstdio>
#include <iostream>
#include <cstring>
#include <cstdlib>
#include <string>
#include <vector>

#define REP(i,n) for(int i = 0, _n = (n); i < _n; i++)
#define REPD(i,n) for(int i = (n) - 1; i >= 0; i--)
#define FOR(i,a,b) for (int i = (a), _b = (b); i <= _b; i++)
#define FORD(i,a,b) for (int i = (a), _b = (b); i >= _b; i--)
#define FORN(i,a,b) for(int i=a;i<b;i++)
#define FOREACH(it,c) for (__typeof((c).begin()) it=(c).begin();it!=(c).end();it++)
#define RESET(c,x) memset (c, x, sizeof (c))

#define maxn 100111
#define mod 1000000007

using namespace std;

int preOrder[maxn], postOrder[maxn], posInPost[maxn], deg[maxn], fact[maxn];
int n, k;

//return x ^ n
int pow (int x, int n) {
    if (n == 0) return 1;

    int res = pow(x, n / 2);
    res = 1LL * res * res % mod;

    if (n % 2) res = 1LL * res * x % mod;

    return res;
}

//return n!/k!/(n - k)!
int C(int n, int k) {
    int numerator   = fact[n];
    int denominator = 1LL * fact[k] * fact[n - k] % mod;

    denominator = pow(denominator, mod - 2);


    return 1LL * numerator * denominator % mod;
}

//check the preOrder[u..v] and postOrder[a..b] is valid or not
bool check(int u, int v, int a, int b) {
    if (v - u != b - a) return false;
    if (u > v) return false;

    int root = preOrder[u];
    if (postOrder[b] != root) return false;
    if (u == v) return true;

    int pos = u + 1;

    while (pos <= v) {
        int child = preOrder[pos];
        deg[root] ++;
        if (deg[root] > k) return false;

        if (posInPost[child] < a || posInPost[child] >= b) return false;
        int num = posInPost[child] - a + 1;

        if (!check(pos, pos + num - 1, a, a + num - 1)) return false;
        pos += num;
        a += num;
    }

    return true;
}


int main() {
    int nTest;
    cin >> nTest;

    // prepare n! values
    fact[0] = 1;
    for (int i = 1; i <= 100000; i++)
        fact[i] = 1LL * fact[i - 1] * i % mod;

    while (nTest--) {
        scanf("%d%d", &n, &k);
        FOR (i, 1, n) scanf("%d", preOrder + i);
        FOR (i, 1, n) scanf("%d", postOrder + i);
        FOR (i, 1, n) posInPost[postOrder[i]] = i;

        int res = 0;

        FOR (i, 1, n) deg[i] = 0;
        if (check(1, n, 1, n)) {
            res = 1;
            for (int i = 1; i <= n; i++)
                res = 1LL * res * C(k, deg[i]) % mod;

            res = (res + mod) % mod;
        }

        printf("%d\n", res);
    }

    return 0;
}
